@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 11.0's 2.6.25 kernel.
+# This is a kernel build script for openSUSE 11.1's 2.6.27 kernel.
 #
 
 die () {
@@ -13,8 +13,8 @@ cd /usr/lib/rpm/ || die "Can't chdir to /usr/lib/rpm/ ."
 if ! grep -q ccs-kernel find-supplements.ksyms
 then
 	patch << "EOF" || die "Can't patch find-supplements.ksyms ."
---- find-supplements.ksyms	2008-05-22 10:02:00.000000000 +0900
-+++ find-supplements.ksyms	2008-06-11 11:04:06.000000000 +0900
+--- find-supplements.ksyms
++++ find-supplements.ksyms
 @@ -7,6 +7,7 @@
  case "$1" in
  kernel-module-*)    ;; # Fedora kernel module package names start with
@@ -29,8 +29,8 @@ fi
 if ! grep -q ccs-kernel find-requires.ksyms
 then
 	patch << "EOF" || die "Can't patch find-requires.ksyms ."
---- find-requires.ksyms	2008-04-16 14:20:34.000000000 +0900
-+++ find-requires.ksyms	2008-04-16 14:21:06.000000000 +0900
+--- find-requires.ksyms
++++ find-requires.ksyms
 @@ -5,6 +5,7 @@
  case "$1" in
  kernel-module-*)    ;; # Fedora kernel module package names start with
@@ -45,8 +45,8 @@ fi
 if ! grep -q ccs-kernel find-provides.ksyms
 then
 	patch << "EOF" || die "Can't patch find-provides.ksyms ."
---- find-provides.ksyms	2008-04-16 14:22:34.000000000 +0900
-+++ find-provides.ksyms	2008-04-16 14:23:04.000000000 +0900
+--- find-provides.ksyms
++++ find-provides.ksyms
 @@ -5,6 +5,7 @@
  case "$1" in
  kernel-module-*)    ;; # Fedora kernel module package names start with
@@ -60,38 +60,43 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.25.20-0.5.src.rpm ]
+if [ ! -r kernel-source-2.6.27.45-0.1.1.src.rpm ]
 then
-    wget http://download.opensuse.org/update/11.0/rpm/src/kernel-source-2.6.25.20-0.5.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.1/rpm/src/kernel-source-2.6.27.45-0.1.1.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-source-2.6.25.20-0.5.src.rpm || die "Can't install source package."
+rpm --checksig kernel-source-2.6.27.45-0.1.1.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-source-2.6.27.45-0.1.1.src.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20100120.tar.gz ]
+if [ ! -r ccs-patch-1.7.2-20100604.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20100120.tar.gz || die "Can't download patch."
+    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20100604.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/packages/SOURCES/kernel-default.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-default.spec	2009-06-02 08:59:34.000000000 +0900
-+++ kernel-default.spec	2009-06-09 12:06:33.000000000 +0900
-@@ -47,10 +47,10 @@
- %define build_nomodules 1
+--- kernel-default.spec
++++ kernel-default.spec
+@@ -63,13 +63,13 @@
+ %if %build_vanilla || %build_kdump || %CONFIG_MODULES != "y"
+ %define split_packages 0
+ %else
+-%define split_packages 1
++%define split_packages 0
  %endif
  
 -Name:           kernel-default
 +Name:           ccs-kernel-default
- Summary:        The Standard Kernel for both Uniprocessor and Multiprocessor Systems
- Version:        2.6.25.20
--Release: 0.5
-+Release: 0.5_tomoyo_1.6.8p3
- License:        GPL v2 or later
+ Summary:        The Standard Kernel
+ Version:        2.6.27.45
+-Release:        0.1.1
++Release:        0.1.1_tomoyo_1.7.2p1
+ License:        GPL v2 only
  Group:          System/Kernel
  Url:            http://www.kernel.org/
-@@ -213,7 +213,7 @@
- %define tolerate_unknown_new_config_options 0
+@@ -242,7 +242,7 @@
+ 
  # kABI change tolerance (default in maintenance should be 4, 6, 8 or 15,
  # 31 is the maximum; see scripts/kabi-checks)
 -%define tolerate_kabi_changes 6
@@ -99,23 +104,40 @@ patch << "EOF" || die "Can't patch spec file."
  
  %description
  The standard kernel for both uniprocessor and multiprocessor systems.
-@@ -315,6 +315,10 @@
- %build
+@@ -342,6 +342,10 @@
  source .rpm-defs
- cd linux-2.6.25
+ 
+ cd linux-2.6.27
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.8-20100120.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.25-suse-11.0.diff
++tar -zxf %_sourcedir/ccs-patch-1.7.2-20100604.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.27-suse-11.1.diff
 +cat config.ccs >> .config
  cp .config .config.orig
  %if %{tolerate_unknown_new_config_options}
  MAKE_ARGS="$MAKE_ARGS -k"
 EOF
-sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
+sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' -e 's:-n kernel:-n ccs-kernel:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
 echo ""
 echo ""
 echo ""
 echo "Edit /tmp/ccs-kernel.spec if needed, and run"
 echo "rpmbuild -bb /tmp/ccs-kernel.spec"
 echo "to build kernel rpm packages."
+echo ""
+echo "I'll start 'rpmbuild -bb --target i586 /tmp/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
+sleep 30
+patch << "EOF" || die "Can't patch spec file."
+--- /tmp/ccs-kernel.spec
++++ /tmp/ccs-kernel.spec
+@@ -97,7 +97,7 @@
+ #!BuildIgnore:  perl-Bootloader mkinitrd
+ 
+ %if ! 0%{?opensuse_bs}
+-BuildRequires:  kernel-dummy
++#BuildRequires:  kernel-dummy
+ %endif
+ %ifarch ia64
+ # arch/ia64/scripts/unwcheck.py
+EOF
+exec rpmbuild -bb --target i586 /tmp/ccs-kernel.spec
 exit 0
